###########################################################################
# maPrint.R
#
# Print methods for microarray classes
#
###########################################################################
# marrayLayout class


setMethod("print", "marrayLayout", function(x)
{
    cat("Array layout:\t Object of class marrayLayout. \n\n")

    cat("Total number of spots:\t\t\t")
    cat(maNspots(x))
    cat("\n")

    cat("Dimensions of grid matrix:\t\t")
    cat(paste( maNgr(x), "rows by", maNgc(x), "cols"))
    cat("\n")

    cat("Dimensions of spot matrices:\t\t")
    cat(paste(maNsr(x), "rows by", maNsc(x), "cols"))
    cat("\n\n")

    if(length(maNspots(x))==1)
      nsub<-length((1:maNspots(x))[maSub(x)])
    else
      nsub<-NULL
    cat(paste("Currently working with a subset of ", nsub, " spots.\n\n", sep=""))

    cat("Control spots: \n")
    if(length(maControls(x))!=0){
      tmp <- table(maControls(x))
      cat(paste("There are  ",  length(tmp),  "types of controls : \n"))
      print(tmp[1:min(10, length(tmp))])
      if(length(tmp) > 10) cat ("...")
    }
    cat("\n\n")

    cat("Notes on layout: \n")
    cat(maNotes(x))
    cat("\n")
  })


#########################
# marrayInfo class

setMethod("print","marrayInfo", function(x)
{
  cat("Object of class marrayInfo. \n\n")

  {

    nr <- length(maLabels(x))
    ds <- dim(maInfo(x))

    if(!is.null(ds))
    {
      if(nr!=0)
      {
        tmp<-data.frame(maLabels(x),maInfo(x))
        dimnames(tmp)[[2]][1]<-"maLabels"
        dimnames(tmp)[[2]][-1]<-dimnames(maInfo(x))[[2]]
      }
      else
	tmp<-maInfo(x)
      print(tmp[1:min(nrow(tmp), 10),])
      if(nrow(tmp) > 10)  cat("... \n")
    }

    if(is.null(ds)&(nr!=0))
    {
      tmp <- as.vector(maLabels(x))
      print(tmp[1:min(length(tmp), 10)])
      if(nr > 10)  cat("... \n")
    }

   cat("\nNumber of labels: ", nr, " \n")
   cat("Dimensions of maInfo matrix: ", ds[1], " rows by ", ds[2], " columns\n")
   }
   cat("\n")

  cat("Notes: \n")
  cat(maNotes(x))

  cat("\n")

})

#########################
# marrayRaw class

setMethod("print","marrayRaw", function(x)
{
  if((length(maGf(x))==0) | (length(maRf(x))==0))
    cat("Input is empty \n")
  else
    {
      cat("Pre-normalization intensity data:\t Object of class marrayRaw. \n\n")

      cat(paste("Number of arrays: \t",ncol(maM(x)), " arrays.\n \n", sep=""))
      cat("A) Layout of spots on the array: \n")
      print(maLayout(x))

      cat("\n")

      cat("B) Samples hybridized to the array: \n")
      print(maTargets(x))
      cat("\n")

      cat("C) Summary statistics for log-ratio distribution: \n")
      results <- apply(maM(x),2, function(x){round(summary(x),2)})
      if(is.matrix(results))
        print(t(results))

      if(is.list(results)){
        x.min <- x.1q <- x.med <- x.mean <- x.3q <- x.max <- x.NA <- NULL
        x.names <- names(results)
        if(is.null(x.names)) x.names <- as.character(1:length(results))
        for(i in 1:length(results)){
          x.min <- c(x.min, results[[i]][1])
          x.1q <- c(x.1q, results[[i]][2])
          x.med <- c(x.med, results[[i]][3])
          x.mean <- c(x.mean, results[[i]][4])
          x.3q <- c(x.3q, results[[i]][5])
          x.max <- c(x.max, results[[i]][6])
          x.NA <- c(x.NA, results[[i]][7])
        }
        y <- data.frame(x.names, x.min, x.1q, x.med, x.mean, x.3q, x.max, as.vector(x.NA))
        dimnames(y)[[2]] <-
          c("   ", "Min.", "1st Qu.", "Median", "Mean", "3rd Qu.", "Max", "NA")
        print(y)
      }

      cat("\n")

      cat("D) Notes on intensity data: \n")
      cat(maNotes(x))
      cat("\n")
    }
})

#########################
# marrayNorm class

setMethod("print","marrayNorm", function(x)
{

  if((length(maA(x))==0) | (length(maM(x))==0))
    cat("Input is empty \n")
  else
  {
  cat("Normalized intensity data:\t Object of class marrayNorm.\n \n")

  cat("Call to normalization function:\n")
  print(maNormCall(x))

  cat(paste("\nNumber of arrays: \t",ncol(maM(x)), " arrays.\n", sep=""))

  cat("\nA) Layout of spots on the array: \n")
  print(maLayout(x))
  cat("\n")

  cat("B) Samples hybridized to the array: \n")
  print(maTargets(x))
  cat("\n")

  cat("C) Summary statistics for log-ratio distribution: \n")
  if(length(maM(x))!=0)
     results <- apply(maM(x),2, function(x){round(summary(x),2)})
      if(is.matrix(results))
        print(t(results))

      if(is.list(results)){
        x.min <- x.1q <- x.med <- x.mean <- x.3q <- x.max <- x.NA <- NULL
        x.names <- names(results)
        if(is.null(x.names)) x.names <- as.character(1:length(results))
        for(i in 1:length(results)){
          x.min <- c(x.min, results[[i]][1])
          x.1q <- c(x.1q, results[[i]][2])
          x.med <- c(x.med, results[[i]][3])
          x.mean <- c(x.mean, results[[i]][4])
          x.3q <- c(x.3q, results[[i]][5])
          x.max <- c(x.max, results[[i]][6])
          x.NA <- c(x.NA, results[[i]][7])
        }
        y <- data.frame(x.names, x.min, x.1q, x.med, x.mean, x.3q, x.max, as.vector(x.NA))
        dimnames(y)[[2]] <-
          c("   ", "Min.", "1st Qu.", "Median", "Mean", "3rd Qu.", "Max", "NA")
        print(y)
      }
  cat("\n")

  cat("D) Notes on intensity data: \n")
  cat(maNotes(x))
  cat("\n")
  }
})


#########################
# marrayTwo class

setMethod("print","marrayTwo", function(x)
{
  printsummary <- function(matrixX)
    {
      results <- apply(matrixX,2, function(x){round(summary(x),2)})
      if(is.matrix(results))
        print(t(results))

      if(is.list(results)){
        x.min <- x.1q <- x.med <- x.mean <- x.3q <- x.max <- x.NA <- NULL
        x.names <- names(results)
        if(is.null(x.names)) x.names <- as.character(1:length(results))
        for(i in 1:length(results)){
          x.min <- c(x.min, results[[i]][1])
          x.1q <- c(x.1q, results[[i]][2])
          x.med <- c(x.med, results[[i]][3])
          x.mean <- c(x.mean, results[[i]][4])
          x.3q <- c(x.3q, results[[i]][5])
          x.max <- c(x.max, results[[i]][6])
          x.NA <- c(x.NA, results[[i]][7])
        }
        y <- data.frame(x.names, x.min, x.1q, x.med, x.mean, x.3q, x.max, as.vector(x.NA))
        dimnames(y)[[2]] <-
          c("   ", "Min.", "1st Qu.", "Median", "Mean", "3rd Qu.", "Max", "NA")
        print(y)
      }
    }
  cat("Object of class marrayTwo. \n\n")

  cat("A) Layout of spots on the array: \n")
  print(maLayout(x))
  cat("\n")

  cat("B) Summary statistics for X: \n")
  if(length(maX(x))!=0)
    printsummary(maX(x))
  cat("\n")

  cat("C) Summary statistics for Y: \n")
  if(length(maY(x))!=0)
    printsummary(maY(x))
  cat("\n")

})

#########################
# marraySpots class

setMethod("print","marraySpots", function(x)
{
  cat("Object of class marraySpots. \n\n")
  cat("A) Layout of spots on the array: \n")
  print(maLayout(x))
  cat("\n")

  cat("B) Names hybridized to the array: \n")
  print(maGnames(x))
  cat("\n")
})


###########################################################################
