\name{marraySpots-class}
\docType{class}

\alias{marraySpots-class}
\alias{marraySpots}

\alias{[,marraySpots-method}
%\alias{coerce,marrayRaw,marraySpots-method}
%\alias{coerce,marrayNorm,marraySpots-method}
\alias{maControls<-,marraySpots-method}
\alias{maControls,marraySpots-method}
%\alias{maGnames<-,marraySpots,marrayInfo-method}
\alias{maGnames,marraySpots-method}
\alias{maGridCol,marraySpots-method}
\alias{maGridRow,marraySpots-method}
%\alias{maLayout<-,marraySpots,marrayLayout-method}
\alias{maLayout,marraySpots-method}
\alias{maNgc<-,marraySpots,numeric-method}
\alias{maNgc,marraySpots-method}
\alias{maNgr<-,marraySpots,numeric-method}
\alias{maNgr,marraySpots-method}
\alias{maNsc<-,marraySpots,numeric-method}
\alias{maNsc,marraySpots-method}
\alias{maNspots<-,marraySpots,numeric-method}
\alias{maNspots,marraySpots-method}
\alias{maNsr<-,marraySpots,numeric-method}
\alias{maNsr,marraySpots-method}
\alias{maPlate<-,marraySpots-method}
\alias{maPlate,marraySpots-method}
\alias{maPrintTip,marraySpots-method}
\alias{maSpotCol,marraySpots-method}
\alias{maSpotRow,marraySpots-method}
\alias{maSub<-,marraySpots-method}
\alias{maSub,marraySpots-method}
\alias{print,marraySpots-method}
\alias{show,marraySpots-method}

%\alias{maGnames}

%\alias{maLayout}
%\alias{maNgr}
%\alias{maNgc}
%\alias{maNsr}
%\alias{maNsc}
%\alias{maNspots}
%\alias{maSub}
%\alias{maPlate}
%\alias{maControls}

\title{Class "marraySpots", classes and methods for probe sequences spotted on microarrays}

\description{This class stores information on the spotted probe sequences for a batch of arrays.
 A \emph{batch of arrays} consists of a collection of arrays with the same layout  (\code{"\link{marrayLayout}"}). The class contains slots for the layout of the arrays, and a description of the probe sequences spotted onto the arrays.}


\section{Objects from the Class}{
Objects can be created by calls of the form 
\code{  new('marraySpots',}\cr
\code{    maGnames = ...., # Object of class marrayInfo}\cr
\code{    maLayout  = ...., # Object of class marrayLayout}\cr
}
\section{Slots}{
  \describe{
    \item{\code{maGnames}:}{Object of class \code{"\link{marrayInfo}"},  description of spotted probe sequences.}
    \item{\code{maLayout}:}{Object of class \code{"\link{marrayLayout}"}, layout parameters for the cDNA microarrays.}
  }
}

\section{Methods}{
  \describe{
    \item{[}{\code{signature(x = "marraySpots")}:  subsetting operator for spots on the array, ensures that all slots are subset properly.}
\item{coerce}{\code{signature(from = "marrayRaw", to = "marraySpots")}: coerce an object of class \code{"\link{marrayRaw}"} into an object of class \code{"\link{marraySpots}"}. }
    \item{coerce}{\code{signature(from = "marrayNorm", to = "marraySpots")}: coerce an object of class \code{"\link{marrayNorm}"} into an object of class \code{"\link{marraySpots}"}. } 
   \item{maControls}{\code{signature(object = "marraySpots")}: slot accessor method.}
    \item{maControls<-}{\code{signature(object = "marraySpots")}:  slot assignment method.} 
    \item{maGnames}{\code{signature(object = "marraySpots")}: slot accessor method.}
    \item{maGnames<-}{\code{signature(object = "marraySpots", value = "marrayInfo")}: slot assignment method.} 
\item{maGridCol}{\code{signature(object = "marraySpots")}:  method which computes a vector of grid column coordinates for each spot.}
    \item{maGridRow}{\code{signature(object = "marraySpots")}: method which computes a vector of grid row coordinates for each spot.}
    \item{maLayout}{\code{signature(object = "marraySpots")}:  slot accessor method.}
    \item{maLayout<-}{\code{signature(object = "marraySpots", value = "marrayLayout")}: slot assignment method.} 
 \item{maNgc}{\code{signature(object = "marraySpots")}: slot accessor method.}
    \item{maNgc<-}{\code{signature(object = "marraySpots", value = "numeric")}: slot assignment method.} 
    \item{maNgr}{\code{signature(object = "marraySpots")}: slot accessor method.}
    \item{maNgr<-}{\code{signature(object = "marraySpots", value = "numeric")}: slot assignment method.} 
    \item{maNsc}{\code{signature(object = "marraySpots")}: slot accessor method.}
    \item{maNsc<-}{\code{signature(object = "marraySpots", value = "numeric")}: slot assignment method.} 
    \item{maNspots}{\code{signature(object = "marraySpots")}: slot accessor method.}
    \item{maNspots<-}{\code{signature(object = "marraySpots", value = "numeric")}: slot assignment method.} 
    \item{maNsr}{\code{signature(object = "marraySpots")}: slot accessor method.}
    \item{maNsr<-}{\code{signature(object = "marraySpots", value = "numeric")}: slot assignment method.} 
    \item{maPlate}{\code{signature(object = "marraySpots")}: slot accessor method.}
    \item{maPlate<-}{\code{signature(object = "marraySpots")}: slot assignment method. }
    \item{maPrintTip}{\code{signature(object = "marraySpots")}: method which computes a vector of print-tip-group indices for each spot.}
    \item{maSpotCol}{\code{signature(object = "marraySpots")}: method which computes a vector of spot column coordinates for each spot.}
    \item{maSpotRow}{\code{signature(object = "marraySpots")}: method which computes a vector of spot row coordinates for each spot.}
    \item{maSub}{\code{signature(object = "marraySpots")}: slot accessor method.}
    \item{maSub<-}{\code{signature(object = "marraySpots")}: slot assignment method.} 
    \item{print}{\code{signature(x = "marraySpots")}: print method for \code{"\link{marraySpots}"} class.}
  }
}


\references{S. Dudoit and Y. H. Yang. (2002). Bioconductor R packages for exploratory analysis and normalization of cDNA microarray data. In G. Parmigiani, E. S. Garrett, R. A. Irizarry and S. L. Zeger, editors, \emph{The Analysis of Gene Expression Data: Methods and Software}, Springer, New York.
}

\author{Sandrine Dudoit, \url{http://www.stat.berkeley.edu/~sandrine}.}

\seealso{\code{\link{marrayLayout}}, \code{\link{marrayRaw}}, \code{\link{marrayNorm}}, \code{\link{marrayInfo}}, \code{\link{marrayTwo}}, \code{\link{print-methods}}, \code{\link{[-methods}}.}


\examples{
## See marrayRaw
}
\keyword{classes}
